import type { CacheAdapter } from "@mikro-orm/core";
import type { Redis, RedisOptions } from "ioredis";
export interface BaseOptions {
    expiration?: number;
    debug?: boolean;
}
export interface BuildOptions extends BaseOptions, RedisOptions {
}
export interface ClientOptions extends BaseOptions {
    client: Redis;
    keyPrefix?: string;
}
export declare type RedisCacheAdapterOptions = BuildOptions | ClientOptions;
export declare class RedisCacheAdapter implements CacheAdapter {
    private readonly client;
    private readonly debug;
    private readonly expiration?;
    private readonly keyPrefix;
    constructor(options: RedisCacheAdapterOptions);
    _getKey(name: string): string;
    get<T = any>(key: string): Promise<T | undefined>;
    set(key: string, data: any, origin: string, expiration?: number | undefined): Promise<void>;
    remove(name: string): Promise<void>;
    clear(): Promise<void>;
    close(): Promise<void>;
}
export default RedisCacheAdapter;
